@@ -1,5 +1,5 @@
 # flake8: noqa
-from strapp.sqlalchemy.model_base import declarative_base
+from strapp.sqlalchemy.model_base import declarative_base, DeclarativeMeta
 from strapp.sqlalchemy.session import create_session, create_session_cls
 
 try:
